==> tine20-allinone_2019.12.5.tar.bz2: Timetracker/js/Timetracker-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: es\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Timesheet, Timesheets"
: [
  "Hoja de hora"
 ,"Hojas de horas"

]
, "Account"
: "Cuenta"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Facturable"

, "Cleared in"
: "Autorizado el"

, "Invoice"
: ""

, "Cleared"
: "Autorizado"

, "Date"
: "Fecha"

, "Start time"
: "Hora de inicio"

, "End time"
: ""

, "Duration"
: "Duración"

, "Description"
: "Descripción"

, "Type"
: ""

, "Time Account closed"
: "Cuenta de Horas cerrada"

, "hour"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Contract"
: ""

, "Title"
: "Título"

, "Number"
: "Número"

, "Price"
: ""

, "Status"
: "Estado"

, "Billed"
: "Facturado"

, "Cleared at"
: ""

, "Booking deadline"
: ""

, "Responsible"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Time Account, Time Accounts"
: [
  "Cuenta de Hora"
 ,"Cuentas de Horas"

]
, "Time Account - Status"
: "Cuenta de Horas - Estado"

, "closed"
: "cerrado"

, "open"
: "abierto"

, "Not a valid time"
: "No es una hora válida"

, "Time Account - Billed"
: ""

, "not yet billed"
: "sin facturar aún"

, "to bill"
: "por facturar"

, "billed"
: "facturado"

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Cleared In"
: "Autorizado El"

, "Select Time Account..."
: "Seleccionar una Cuenta de Hora..."

, "Start"
: "Comenzar"

, "not set"
: "no establecido"

, "End"
: ""

, "Enter description..."
: "Escribir descripción..."

, "Need for Clarification"
: ""

, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Reserva Pripia"

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Ver Todos"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: "Reservar Todos"

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: "Administrar Autorizaciones"

, "The grant to manage clearing of Timesheets"
: ""

, "without contract"
: ""

, "without responsible"
: ""

, "timeframe"
: "calendario"

, "summary"
: "resumen"

, "Total Timesheets"
: "Total de Hojas de Horas"

, "Billable Timesheets"
: "Hojas de Horas Facturables"

, "Total Time"
: "Tiempo Total"

, "Time of Billable Timesheets"
: "Tiempo de Las Hojas de Horas Facturables"

, "Detail"
: "Detalle"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "Exportar como ODS"

, "Export as CSV"
: "Exportar como CVS"

, "Export as ..."
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Unidad"

, "Unit Price"
: "Precio por Unidad"

, "Budget"
: "Presupuesto"

, "Timesheets are billable"
: "Hojas de horas son facturables"

, "Access"
: "Acceso"

, "Permissions"
: "Permisos"

, "Show closed"
: "Función cerrada"

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "Working time"
: ""

, "Project time"
: ""

, "none"
: ""

, "last week"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Manage timeaccounts"
: "Administrar Cuentas de Horas"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "Timetracker"
: "Rastreador de Tiempo"

, "Timesheet"
: "Hoja de hora"

, "Timeaccount"
: ""

, "Time Account"
: "Cuenta de Hora"

, "Delete {0}"
: ""

, "Timeaccount Grant"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.03.4.tar.bz2: Timetracker/js/Timetracker-lang-es-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Timetracker **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Timetracker'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 13:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Responsible"
: ""

, "without responsible"
: ""

, "Bookmark Timeaccount"
: ""

, "Close Timeaccount"
: ""

, "timeframe"
: "calendario"

, "summary"
: "resumen"

, "Total Timesheets"
: "Total de Hojas de Horas"

, "Billable Timesheets"
: "Hojas de Horas Facturables"

, "Total Time"
: "Tiempo Total"

, "Time of Billable Timesheets"
: "Tiempo de Las Hojas de Horas Facturables"

, "Description"
: "Descripción"

, "Detail"
: "Detalle"

, "Assign '{0}' Tag"
: ""

, "Export Timesheets"
: ""

, "Export as ODS"
: "Exportar como ODS"

, "Export as CSV"
: "Exportar como CVS"

, "Export as ..."
: ""

, "Timesheet, Timesheets"
: [
  "Hoja de hora"
 ,"Hojas de horas"

]
, "Accounting"
: ""

, "Timeaccount, Timeaccounts"
: [
  ""
 ,""

]
, "Failed"
: ""

, "Could not save {0}."
: ""

, "Booking deadline for this Timeaccount has been exceeded."
: ""

, "Closed Timeaccount Warning!"
: ""

, "The selected Time Account is already closed."
: ""

, "The selected Time Account is already closed. Do you wish to continue anyway?"
: ""

, "Contract"
: ""

, "without contract"
: ""

, "Add New Timeaccount"
: ""

, "Unit"
: "Unidad"

, "Unit Price"
: "Precio por Unidad"

, "Factor"
: ""

, "Budget"
: "Presupuesto"

, "Status"
: "Estado"

, "closed"
: "cerrado"

, "open"
: "abierto"

, "Cleared In"
: "Autorizado El"

, "Cleared at"
: ""

, "Cost Center"
: ""

, "Responsible Person"
: ""

, "Timesheets are billable"
: "Hojas de horas son facturables"

, "Invoice"
: ""

, "Time Account, Time Accounts"
: [
  "Cuenta de Hora"
 ,"Cuentas de Horas"

]
, "Number"
: "Número"

, "Title"
: "Título"

, "Access"
: "Acceso"

, "Permissions"
: "Permisos"

, "Time Account - Billed"
: ""

, "not yet billed"
: "sin facturar aún"

, "to bill"
: "por facturar"

, "billed"
: "facturado"

, "Time Account - Status"
: "Cuenta de Horas - Estado"

, "Timeaccount Grant, Timeaccount Grants"
: [
  ""
 ,""

]
, "Book Own"
: "Reserva Pripia"

, "The grant to add Timesheets to this Timeaccount"
: ""

, "View All"
: "Ver Todos"

, "The grant to view Timesheets of other users"
: ""

, "Book All"
: "Reservar Todos"

, "The grant to add Timesheets for other users"
: ""

, "Manage Clearing"
: "Administrar Autorizaciones"

, "The grant to manage clearing of Timesheets"
: ""

, "Timeaccount Favorites"
: ""

, "Delete {0}, Delete {0}"
: [
  ""
 ,""

]
, "Favorite"
: ""

, "Show closed"
: "Función cerrada"

, "Timesheets ODS export configuration"
: ""

, "Use this configuration for the timesheet ODS export."
: ""

, "A Tag which is available in context menu for fast assignment"
: ""

, "Quick Tag allows to simply assign a predefined tag by the context menu."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Timetracker Application."
: ""

, "Timeaccount Bookmarks"
: ""

, "none"
: ""

, "last week"
: ""

, "status to bill"
: ""

, "Add timeaccounts as favorite to speedup timesheet creation.)"
: ""

, "Price"
: ""

, "Cleared in"
: "Autorizado el"

, "Billed"
: "Facturado"

, "Booking deadline"
: ""

, "Accounting time factor"
: ""

, "hour"
: ""

, "Account"
: "Cuenta"

, "Time Account (Number - Title)"
: ""

, "Billable"
: "Facturable"

, "Cleared"
: "Autorizado"

, "Date"
: "Fecha"

, "Start time"
: "Hora de inicio"

, "End time"
: ""

, "Duration"
: "Duración"

, "Need for Clarification"
: ""

, "Accounting time"
: ""

, "Workingtime is cleared"
: ""

, "Workingtime cleared in"
: ""

, "Time Account closed"
: "Cuenta de Horas cerrada"

, "Timetracker"
: "Rastreador de Tiempo"

, "Timeaccounts to bill"
: ""

, "Timeaccounts not yet billed"
: ""

, "Timeaccounts already billed"
: ""

, "My Timesheets today"
: ""

, "My Timesheets this week"
: ""

, "My Timesheets last week"
: ""

, "My Timesheets this month"
: ""

, "My Timesheets last month"
: ""

, "Manage timeaccounts"
: "Administrar Cuentas de Horas"

, "Add, edit and delete timeaccounts (includes all timesheet grants)"
: ""

, "Add timeaccounts"
: ""

, "Manage shared timeaccount favorites"
: ""

, "Create or update shared timeaccount favorites"
: ""

, "Manage shared timesheet favorites"
: ""

, "Create or update shared timesheet favorites"
: ""






, "Timesheet"
: "Hoja de hora"

, "Timeaccount"
: ""

, "Time Account"
: "Cuenta de Hora"

, "Timeaccount Grant"
: ""

, "Delete {0}"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
